@@ -1,4 +1,4 @@
 """Collection of reinforcement learning algorithms."""
-from ray.rllib.agents import with_common_config
 
 from .trainer import Trainer
+from .trainer import with_common_config
