@@ -258,9 +258,9 @@ class TorchPolicy(Policy):
         return sample_batch
 
     @override(Policy)
-    def get_weights(self):
+    def get_weights(self) -> dict:
         state = {
-            "module": self.module.state_dict(),
+            "module": copy.deepcopy(self.module.state_dict()),
             "optimizers": copy.deepcopy(self.optimizers.state_dict()),
         }
 
@@ -268,7 +268,7 @@ class TorchPolicy(Policy):
         return state
 
     @override(Policy)
-    def set_weights(self, weights):
+    def set_weights(self, weights: dict):
         state = weights
         _from_numpy_state_dict(state)
 
@@ -333,4 +333,4 @@ def _from_numpy_state_dict(mapping, device=None):
         if isinstance(val, np.ndarray):
             mapping[key] = convert_to_tensor(val, device)
         elif isinstance(val, dict):
-            _from_numpy_state_dict(val)
+            _from_numpy_state_dict(val, device)
